from django.db import models
from django.contrib.auth.models import AbstractUser
from mimir import constants



class CustomUser(AbstractUser):
    """
    Parent class needed for authetication 
    """    
    # User types will inherit username, email and password fields
    pass    
    

class BusinessUser(CustomUser):
    """
    Business user type. 
    Related to AppUser by field AppUser.owner
    """

    taxID = models.CharField(
                    max_length=9, 
                    blank=False
    )

class Permission(models.Model):
    """
    Permission for AppUser. 
    Choices are located in choices.py in root directory
    Related to AppUser by field AppUSer.Permissions
    """
    name = models.CharField(
               max_length=50,
               unique=True
    )
    description = models.CharField(
                      max_length=500
    )
    entity = models.CharField(
                 choices=constants.ENTITY, 
                 max_length=20
    )
    attribute = models.CharField(
                    choices=constants.ATTRIBUTE, 
                    max_length=20,
                    blank=True
    )
    type = models.CharField(
               choices=constants.TYPE,
               max_length=20
    )
    access_type = models.CharField(
                      choices=constants.ACCESS_TYPE,
                      max_length=20,
                      blank=True
    )

    def __str__(self):
        return self.name

class AppUser(CustomUser):
    """
    Application user type.
    Related to BusinessUser and Permissions by ForeignKey 
    """
   
    description = models.TextField()

    # In BusinessUser field with AppUsers named apps can be serialized
    owner = models.ForeignKey(
                'BusinessUser', 
                related_name='apps', 
                on_delete=models.CASCADE
    )

    #Many to many relationship with Permission. 
    # In Permissions field with AppUsers named apps can be serialized
    permissions = models.ManyToManyField(
                      Permission, 
                      related_name='apps'
    )
    active = models.BooleanField(
                 default=False
    )
   
    def is_activated(self):
        """
        Method to retrieve if AppUser account is activated
        """
        return self.active

