from rest_framework import permissions
from .models import AppUser, BusinessUser
from django.core.exceptions import ObjectDoesNotExist

class IsBusinessOrAdmin(permissions.BasePermission):

    """
    Custom permission to allow only Business to create Apps
    """
    
    def has_permission(self, request, view):
    
        if (request.user.is_staff):
            return True
        try:
            user = BusinessUser.objects.get(username=request.user)
        except ObjectDoesNotExist:
            return False 
        return True

class IsAppOrAdmin( permissions.BasePermission ):

    """
    Custom permission to allow only Apps to access Orion
    """

    def has_permission(self, request, view):
    
        if (request.user.is_staff):
            return True
        try:
            user = AppUser.objects.get(username=request.user)
        except ObjectDoesNotExist:
            return False 
        return True

class IsActivated( permissions.BasePermission ):
    """
    Custom permission to allow only active Apps to access Orion
    """

    def has_permission( self, request, view ):
        try:
            user = AppUser.objects.get(username=request.user)
        except ObjectDoesNotExist:
            return False
        if( user.is_activated() ):
            return True
        else:
            return False
        
