from rest_framework import serializers

class PersonSerializerSlim(serializers.Serializer):
    """
    Serializer for Person entities from Orion
    This serializer is for requests with query param: "options=keyValues"
    """
    address = serializers.CharField(max_length=400)
    birthDate = serializers.CharField(max_length=10)
    birthPlace = serializers.CharField(max_length=50)
    familyName = serializers.CharField(max_length=200)
    gender = serializers.CharField(max_length=10)
    givenName  = serializers.CharField(max_length=100)
    id = serializers.CharField(
             read_only=True,
             max_length=9 
    )
    type = serializers.CharField(read_only=True)
    nationality = serializers.CharField(max_length=20)
    parkingCard = serializers.IntegerField()

    def create(self, validated_data):
        """
        Method to create Person instances 
        """
        return Person(id=None, **validated_data)

    def update(self, instance, validated_data):
        """
        Method to update Person instances 
        """
        for field, value in validated_data.items():
            setattr(instance, field, value) 

    def to_representation(self, instance):
        """
           Method to delete None fields from serializer representation
        """
        ret = super(PersonSerializerSlim, self).to_representation(instance)
        fields = self._readable_fields
 
        for field in ret:
            if ret.get(field) is None:
                ret.pop(field)
        return ret

class PersonSerializer(serializers.Serializer):
    """
    Serializer for Person entities from Orion
    """

    address = serializers.JSONField()
    birthDate = serializers.JSONField()
    birthPlace = serializers.JSONField()
    familyName = serializers.JSONField()
    gender = serializers.JSONField()
    givenName = serializers.JSONField()
    id = serializers.CharField(read_only=True, 
                                        max_length=9
    )
    type = serializers.CharField(read_only=True)
    nationality = serializers.JSONField()
    parkingCard = serializers.JSONField()

    def create(self, validated_data):
        """
        Method to create Person instances 
        """
        return Person(id=None, **validated_data)

    def update(self, instance, validated_data):
        """
        Method to update Person instances 
        """
        for field, value in validated_data.items():
            setattr(instance, field, value) 

    def to_representation(self, instance):
        """
           Method to delete None fields from serializer representation
        """
        ret = super(PersonSerializer, self).to_representation(instance)
        fields = self._readable_fields
 
        for field in ret:
            if ret.get(field) is None:
                ret.pop(field)
        return ret

class VehicleSerializerSlim(serializers.Serializer):
    """
    Serializer for Vehicle entities from Orion
    This serializer is for requests with query param: "options=keyValues"
    """
    
    brand = serializers.CharField(max_length=100)
    color = serializers.CharField( max_length=10)
    fiscalPower = serializers.FloatField()
    fuelType = serializers.CharField(max_length=20)
    id = serializers.CharField(read_only=True, 
                               max_length=7 
    )
    type = serializers.CharField(read_only=True)
    model = serializers.CharField(max_length=50)
    owner = serializers.CharField(max_length=9)
    
    def create(self, validated_data):
        """
        Method to create Vehicle instances 
        """
        return Vehicle(id=None, **validated_data)

    def update(self, instance, validated_data):
        """
        Method to create Vehicle instances 
        """
        for field, value in validated_data.items():
            setattr(instance, field, value) 

    def to_representation(self, instance):
        """
           Method to delete None fields from serializer representation
        """
        ret = super(VehicleSerializerSlim, self).to_representation(instance)
        fields = self._readable_fields
 
        for field in ret:
            if ret.get(field) is None:
                ret.pop(field)
        return ret

class VehicleSerializer(serializers.Serializer):
    """
    Serializer for Vehicle entities from Orion
    """
    
    brand = serializers.JSONField()
    color = serializers.JSONField()
    fiscalPower = serializers.JSONField()
    fuelType = serializers.JSONField()
    id = serializers.CharField(read_only=True, 
                               max_length=7
    )
    type = serializers.CharField( read_only = True )
    model = serializers.JSONField()
    owner = serializers.JSONField()
    
    def create(self, validated_data):
        """
        Method to create Vehicle instances 
        """
        return Vehicle(id=None, **validated_data)

    def update(self, instance, validated_data):
        """
        Method to create Vehicle instances 
        """
        for field, value in validated_data.items():
            setattr(instance, field, value) 

    def to_representation(self, instance):
        """
           Method to delete None fields from serializer representation
        """
        ret = super(VehicleSerializer, self).to_representation(instance)
        fields = self._readable_fields
 
        for field in ret:
            if ret.get(field) is None:
                ret.pop(field)
        return ret
